%%====================================================================%
%%                              BscUS.cls
%%                         -------------------
%%  Date & ver : 2009/06/18 v1.00
%%  University : Uniwersytet Slaski
%%               Wydzial Matematyki, Fizyki i Chemii
%%  Author     : Marcin Malich <me@malcom.pl>
%%
%% Copyright 2009 by Marcin Malich <me@malcom.pl>
%%--------------------------------------------------------------------%
%% BscUSMFC jest klasa systemu LaTeX dla skladu prac licencjackich
%% Uniwersytetu Slaskiego, przygotowana glownie na potrzeby pracy
%% licencjackiej autora na wydziale Matematyki, Fizyki i Chemii.
%%--------------------------------------------------------------------%
%% This work may be distributed and/or modified under the
%% conditions of the LaTeX Project Public License, either version 1.3
%% of this license or (at your option) any later version.
%% The latest version of this license is in
%%   http://www.latex-project.org/lppl.txt
%% and version 1.3 or later is part of all distributions of LaTeX
%% version 2005/12/01 or later.
%%====================================================================%

\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{BscUS}[2009/06/18 v1.00 BSc for University of Silesia]

\def\@baseclass{report}
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{\@baseclass}}
\PassOptionsToClass{12pt,a4paper}{\@baseclass}
\ProcessOptions
\LoadClass{\@baseclass}

\RequirePackage{polski}
\RequirePackage{ifthen}

\RequirePackage{geometry}
\geometry{verbose,a4paper,tmargin=2.5cm,bmargin=2.5cm,lmargin=3.5cm,rmargin=1.5cm}

\RequirePackage[pdftex,pdfstartview=FitH,unicode]{hyperref}

\RequirePackage{caption}
\captionsetup{font=small,format=plain,labelsep=period,figurename=Rys.,tablename=Tab.}


\linespread{1.3} % interlinia 1.5


\def\university#1{\def\university{#1}}
\def\@university{Uniwersytet {\'S}l\k{a}ski}

\def\faculty#1{\gdef\@faculty{#1}}
\def\@faculty{Wydzia{\l} Matematyki, Fizyki i Chemii}

\def\title#1{\gdef\@title{#1}}
\def\@title{???\ClassError{BscUS}{Brak tytulu pracy}\@ehc}

\def\keywords#1{\gdef\@keywords{#1}}
\def\@keywords{???\ClassError{BscUS}{Brak slow kluczowych}\@ehc}

\def\author#1{\gdef\@author{#1}}
\def\@author{???\ClassError{BscUS}{Brak autora pracy}\@ehc}

\def\album#1{\gdef\@album{#1}}
\def\@album{???\ClassError{BscUS}{Brak numeru albumu autora}\@ehc}

\def\promoter#1{\gdef\@promoter{#1}}
\def\@promoter{???\ClassError{BscUS}{Brak opiekuna pracy}\@ehc}

\def\where#1{\gdef\@where{#1}}
\def\@where{Katowice}

\def\when#1{\gdef\@when{#1}}
\def\@when{\number\year}

\def\statementAgree#1{\gdef\@statementAgree{#1}}
\def\@statementAgree{yes}

\def\statementDate#1{\gdef\@statementDate{#1}}
\def\@statementDate{\@date r.}

\def\statementSex#1{\gdef\@statementSex{#1}}
\def\@statementSex{m}


\newcommand\updatepdfmeta{
	\ifpdf
		\pdfcompresslevel=9
		\hypersetup{pdfauthor={\@author},pdftitle={\@title},pdfkeywords={\@keywords}}
	\fi
} % newcommand: updatepdfmeta

\AtBeginDocument{\updatepdfmeta}


\renewcommand\maketitle{
	\begin{titlepage}
		\setcounter{page}{-1}
		\begin{center}
			{\@university}\\{\@faculty}
			\vfill
			{\bf \Large {\@author} \par}
			{\bf Nr albumu: {\@album}}
			\vskip 24pt
			{\large Praca licencjacka \par}
			\vfill
			{\bf \LARGE {\@title} \par}
			\vfill\vfill\vfill
			\begin{flushright}
			\begin{tabular}{p{55mm}}
				Promotor:\\
				{\@promoter}
			\end{tabular}
			\end{flushright}
			\vfill
			{\@where, \@when}
		\end{center}
	\end{titlepage}
} % renewcommand: maketitle


\newcommand\makestatement{
	\clearpage
	\thispagestyle{empty}
	\setcounter{page}{0}
	\null\vfill
	\ifthenelse{\equal{\@statementAgree}{yes}}%
	{Wyra{\.z}am zgod\k{e}}{Nie wyra{\.z}am zgody}
	na udost{\k{e}}pnienie mojej pracy dyplomowej dla cel{\'o}w na\-uko\-wo-ba\-da\-wczych.
	\vskip 36pt
	\hfill {\@statementDate} \hfill\hfill\hfill {\@author} \hfill\null
	\vfill
	S{\l}owa kluczowe: {\@keywords}.
	\vfill
	\begin{center}
		\line(1,0){400}
	\end{center}
	\vfill
	
	\begin{center}
		\bf O{\'s}wiadczenie
	\end{center}

	\ifthenelse{\equal{\@statementSex}{m}}{\'Swiadomy}{\'Swiadoma}
	odpowiedzialno{\'s}ci prawnej o{\'s}wiadczam, {\.z}e niniejsza praca
	dyplomowa zosta{\l}a napisana przeze mnie samodzielnie i~nie zawiera
	tre{\'s}ci uzyskanych w~spos{\'o}b niezgodny z~obowi{\k{a}}zuj{\k{a}}cymi
	przepisami.

	O{\'s}wiadczam r{\'o}wnie{\.z}, {\.z}e przedstawiona praca nie by{\l}a
	wcze{\'s}niej przedmiotem procedur zwi{\k{a}}zanych z~uzyskaniem tytu{\l}u
	zawodowego w~wy{\.z}szej uczelni.

	O{\'s}wiadczam ponadto, {\.z}e niniejsza wersja pracy jest identyczna
	z~za{\l}{\k{a}}czon{\k{a}} wersj{\k{a}} elektroniczn{\k{a}}.

	\vskip 36pt
	\hfill {\@statementDate} \hfill\hfill\hfill {\@author} \hfill\null
	\vfill\vfill
} % newcommand: makestatement


\makeatletter

% naglowki numerowane z kropka, bez prefixu 'Rozdzia'
\renewcommand{\@makechapterhead}[1]{%
	\vspace*{72pt}%
	{\raggedright\normalfont\bfseries\LARGE\thechapter.\ #1
	 \par\nobreak\vspace{36pt}}
}

% naglowki bez numerow, kompatybilnosc stylu
\renewcommand{\@makeschapterhead}[1]{%
	\vspace*{72pt}%
	{\raggedright\normalfont\bfseries\LARGE #1
	 \par\nobreak\vspace{36pt}}
}

% kropki po numerach sekcji
\renewcommand\@seccntformat[1]{\csname the#1\endcsname.\ }

% kropki po numrach w spisie tresci
\renewcommand\numberline[1]{#1.\hskip0.7em}

\makeatother
